@@ -25,7 +25,7 @@
 #include "ConfigDlg.h"
 #include "StringTable.h"
 
-CConfigDlg::CConfigDlg(QWidget* parent=0, const char* name=0, WFlags fl=0):ConfigDlgBase( parent, name, fl )
+CConfigDlg::CConfigDlg(QWidget* parent, const char* name, WFlags fl):ConfigDlgBase( parent, name, fl )
 {
 
   setCaption( STRING_UTF8(ID_STRING_1000) );
