@@ -22,7 +22,11 @@
 #ifndef MAINWIN_H
 #define MAINWIN_H
 
+#ifdef DESKTOP
+#include <qmenubar.h>
+#else
 #include <qpe/qpemenubar.h>
+#endif
 #include <qmainwindow.h>
 #include <qpopupmenu.h>
 #include "gameWidget.h"
