@@ -1,5 +1,9 @@
-
+#ifdef DESKTOP
+#include <qapplication.h>
+#else
 #include <qpe/qpeapplication.h>
+#endif
+
 #include <qstring.h>
 
 class CMessage : QObject{
